pub struct CreateDecreasePositionRequest2InstructionArgs {
pub collateral_usd_delta: u64,
pub size_usd_delta: u64,
pub request_type: RequestType,
pub price_slippage: Option<u64>,
pub jupiter_minimum_out: Option<u64>,
pub trigger_price: Option<u64>,
pub trigger_above_threshold: Option<bool>,
pub entire_position: Option<bool>,
pub counter: u64,
}Fields
collateral_usd_delta: u64size_usd_delta: u64request_type: RequestTypeprice_slippage: Option<u64>jupiter_minimum_out: Option<u64>trigger_price: Option<u64>trigger_above_threshold: Option<bool>entire_position: Option<bool>counter: u64Trait Implementations
Sourceimpl BorshDeserialize for CreateDecreasePositionRequest2InstructionArgs
impl BorshDeserialize for CreateDecreasePositionRequest2InstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateDecreasePositionRequest2InstructionArgs
impl Clone for CreateDecreasePositionRequest2InstructionArgs
Sourcefn clone(&self) -> CreateDecreasePositionRequest2InstructionArgs
fn clone(&self) -> CreateDecreasePositionRequest2InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateDecreasePositionRequest2InstructionArgs
impl PartialEq for CreateDecreasePositionRequest2InstructionArgs
Sourcefn eq(&self, other: &CreateDecreasePositionRequest2InstructionArgs) -> bool
fn eq(&self, other: &CreateDecreasePositionRequest2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateDecreasePositionRequest2InstructionArgs