pub struct CreateTokenMetadataInstructionArgs {
pub name: String,
pub symbol: String,
pub uri: String,
}Fields
name: Stringsymbol: Stringuri: StringTrait Implementations
Sourceimpl BorshDeserialize for CreateTokenMetadataInstructionArgs
impl BorshDeserialize for CreateTokenMetadataInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateTokenMetadataInstructionArgs
impl Clone for CreateTokenMetadataInstructionArgs
Sourcefn clone(&self) -> CreateTokenMetadataInstructionArgs
fn clone(&self) -> CreateTokenMetadataInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateTokenMetadataInstructionArgs
impl PartialEq for CreateTokenMetadataInstructionArgs
Sourcefn eq(&self, other: &CreateTokenMetadataInstructionArgs) -> bool
fn eq(&self, other: &CreateTokenMetadataInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateTokenMetadataInstructionArgs