pub struct InstantCreateLimitOrderInstructionArgs {
pub size_usd_delta: u64,
pub collateral_token_delta: u64,
pub side: Side,
pub trigger_price: u64,
pub trigger_above_threshold: bool,
pub counter: u64,
pub request_time: i64,
}Fields
size_usd_delta: u64collateral_token_delta: u64side: Sidetrigger_price: u64trigger_above_threshold: boolcounter: u64request_time: i64Trait Implementations
Sourceimpl BorshDeserialize for InstantCreateLimitOrderInstructionArgs
impl BorshDeserialize for InstantCreateLimitOrderInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for InstantCreateLimitOrderInstructionArgs
impl Clone for InstantCreateLimitOrderInstructionArgs
Sourcefn clone(&self) -> InstantCreateLimitOrderInstructionArgs
fn clone(&self) -> InstantCreateLimitOrderInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for InstantCreateLimitOrderInstructionArgs
impl PartialEq for InstantCreateLimitOrderInstructionArgs
Sourcefn eq(&self, other: &InstantCreateLimitOrderInstructionArgs) -> bool
fn eq(&self, other: &InstantCreateLimitOrderInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InstantCreateLimitOrderInstructionArgs