pub struct OperatorSetPoolConfigCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a, 'b> OperatorSetPoolConfigCpiBuilder<'a, 'b>
impl<'a, 'b> OperatorSetPoolConfigCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn operator(&mut self, operator: &'b AccountInfo<'a>) -> &mut Self
pub fn pool(&mut self, pool: &'b AccountInfo<'a>) -> &mut Self
pub fn fees(&mut self, fees: Fees) -> &mut Self
pub fn limit(&mut self, limit: Limit) -> &mut Self
pub fn max_request_execution_sec( &mut self, max_request_execution_sec: i64, ) -> &mut Self
pub fn max_trigger_price_diff_bps( &mut self, max_trigger_price_diff_bps: u64, ) -> &mut Self
pub fn disable_close_position_request( &mut self, disable_close_position_request: bool, ) -> &mut Self
pub fn max_lp_token_price_change_bps( &mut self, max_lp_token_price_change_bps: u64, ) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult