pub struct OperatorSetPoolConfigInstructionArgs {
pub fees: Fees,
pub limit: Limit,
pub max_request_execution_sec: i64,
pub max_trigger_price_diff_bps: u64,
pub disable_close_position_request: bool,
pub max_lp_token_price_change_bps: u64,
}Fields
fees: Feeslimit: Limitmax_request_execution_sec: i64max_trigger_price_diff_bps: u64disable_close_position_request: boolmax_lp_token_price_change_bps: u64Trait Implementations
Sourceimpl BorshDeserialize for OperatorSetPoolConfigInstructionArgs
impl BorshDeserialize for OperatorSetPoolConfigInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OperatorSetPoolConfigInstructionArgs
impl Clone for OperatorSetPoolConfigInstructionArgs
Sourcefn clone(&self) -> OperatorSetPoolConfigInstructionArgs
fn clone(&self) -> OperatorSetPoolConfigInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for OperatorSetPoolConfigInstructionArgs
impl PartialEq for OperatorSetPoolConfigInstructionArgs
Sourcefn eq(&self, other: &OperatorSetPoolConfigInstructionArgs) -> bool
fn eq(&self, other: &OperatorSetPoolConfigInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OperatorSetPoolConfigInstructionArgs