pub struct SetPoolConfigInstructionArgs {
pub fees: Fees,
pub limit: Limit,
pub max_request_execution_sec: i64,
pub parameter_update_oracle: Secp256k1Pubkey,
pub max_trigger_price_diff_bps: u64,
pub disable_close_position_request: bool,
pub max_lp_token_price_change_bps: u64,
}Fields
fees: Feeslimit: Limitmax_request_execution_sec: i64parameter_update_oracle: Secp256k1Pubkeymax_trigger_price_diff_bps: u64disable_close_position_request: boolmax_lp_token_price_change_bps: u64Trait Implementations
Sourceimpl BorshDeserialize for SetPoolConfigInstructionArgs
impl BorshDeserialize for SetPoolConfigInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SetPoolConfigInstructionArgs
impl Clone for SetPoolConfigInstructionArgs
Sourcefn clone(&self) -> SetPoolConfigInstructionArgs
fn clone(&self) -> SetPoolConfigInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetPoolConfigInstructionArgs
impl Debug for SetPoolConfigInstructionArgs
Sourceimpl PartialEq for SetPoolConfigInstructionArgs
impl PartialEq for SetPoolConfigInstructionArgs
Sourcefn eq(&self, other: &SetPoolConfigInstructionArgs) -> bool
fn eq(&self, other: &SetPoolConfigInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SetPoolConfigInstructionArgs