pub struct Assets {
pub fees_reserves: u64,
pub owned: u64,
pub locked: u64,
pub guaranteed_usd: u64,
pub global_short_sizes: u64,
pub global_short_average_prices: u64,
}Fields
fees_reserves: u64owned: u64locked: u64guaranteed_usd: u64global_short_sizes: u64global_short_average_prices: u64Trait Implementations
Sourceimpl BorshDeserialize for Assets
impl BorshDeserialize for Assets
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Assets
impl BorshSerialize for Assets
impl StructuralPartialEq for Assets