pub struct JumpRateState {
pub min_rate_bps: u64,
pub max_rate_bps: u64,
pub target_rate_bps: u64,
pub target_utilization_rate: u64,
}Fields
min_rate_bps: u64max_rate_bps: u64target_rate_bps: u64target_utilization_rate: u64Trait Implementations
Sourceimpl BorshDeserialize for JumpRateState
impl BorshDeserialize for JumpRateState
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for JumpRateState
impl BorshSerialize for JumpRateState
Sourceimpl Clone for JumpRateState
impl Clone for JumpRateState
Sourcefn clone(&self) -> JumpRateState
fn clone(&self) -> JumpRateState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JumpRateState
impl Debug for JumpRateState
Sourceimpl PartialEq for JumpRateState
impl PartialEq for JumpRateState
Sourcefn eq(&self, other: &JumpRateState) -> bool
fn eq(&self, other: &JumpRateState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for JumpRateState