pub struct Limit {
pub max_aum_usd: u128,
pub token_weightage_buffer_bps: u128,
pub buffer: u64,
}Fields
max_aum_usd: u128token_weightage_buffer_bps: u128buffer: u64Trait Implementations
Sourceimpl BorshDeserialize for Limit
impl BorshDeserialize for Limit
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Limit
impl BorshSerialize for Limit
impl StructuralPartialEq for Limit