pub struct OracleParams {
pub oracle_account: Pubkey,
pub oracle_type: OracleType,
pub buffer: u64,
pub max_price_age_sec: u32,
}Fields
oracle_account: Pubkeyoracle_type: OracleTypebuffer: u64max_price_age_sec: u32Trait Implementations
Sourceimpl BorshDeserialize for OracleParams
impl BorshDeserialize for OracleParams
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OracleParams
impl BorshSerialize for OracleParams
Sourceimpl Clone for OracleParams
impl Clone for OracleParams
Sourcefn clone(&self) -> OracleParams
fn clone(&self) -> OracleParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OracleParams
impl Debug for OracleParams
Sourceimpl PartialEq for OracleParams
impl PartialEq for OracleParams
Sourcefn eq(&self, other: &OracleParams) -> bool
fn eq(&self, other: &OracleParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OracleParams