pub struct OraclePrice {
pub price: u64,
pub exponent: i32,
}Fields
price: u64exponent: i32Trait Implementations
Sourceimpl BorshDeserialize for OraclePrice
impl BorshDeserialize for OraclePrice
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OraclePrice
impl BorshSerialize for OraclePrice
Sourceimpl Clone for OraclePrice
impl Clone for OraclePrice
Sourcefn clone(&self) -> OraclePrice
fn clone(&self) -> OraclePrice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OraclePrice
impl Debug for OraclePrice
Sourceimpl PartialEq for OraclePrice
impl PartialEq for OraclePrice
Sourcefn eq(&self, other: &OraclePrice) -> bool
fn eq(&self, other: &OraclePrice) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OraclePrice