pub struct PoolApr {
pub last_updated: i64,
pub fee_apr_bps: u64,
pub realized_fee_usd: u64,
}Fields
last_updated: i64fee_apr_bps: u64realized_fee_usd: u64Trait Implementations
Sourceimpl BorshDeserialize for PoolApr
impl BorshDeserialize for PoolApr
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PoolApr
impl BorshSerialize for PoolApr
impl StructuralPartialEq for PoolApr